import { useEffect } from 'react'
import { useQuery } from '@tanstack/react-query'
import { getUser, getMapList, getMyList, getMyField } from '@/api/base'
import { useUserStore } from '@/stores/user'
import { useMapStore } from '@/stores/map'
import axios from 'axios'
import { read, utils } from 'xlsx'

export function useUserQuery() {
  const { setUser } = useUserStore()

  const query = useQuery({ queryKey: ['user'], queryFn: getUser, select: (res) => res.data })

  useEffect(() => {
    if (query.data) {
      setUser(query.data)
    }
  }, [query.data, setUser])

  return query
}

export function useMapQuery() {
  const { setMap } = useMapStore()

  const query = useQuery({ queryKey: ['dictionary'], queryFn: getMapList, select: (res) => res.data })

  useEffect(() => {
    if (query.data) {
      setMap(query.data)
    }
  }, [query.data, setMap])

  return query
}

// 我的数据集
export function useDataQuery() {
  const query = useQuery({
    queryKey: ['data'],
    queryFn: () => {
      return getMyList({ page: 1, 'per-page': 1000 })
    },
    select: (res) => res.data,
    placeholderData: (): any => {
      return { data: { total: 0, list: [], title: [] } }
    },
  })
  useEffect(() => {
    if (query.data?.info) {
      const file = query.data.info.source
      axios(file.url, { responseType: 'arraybuffer' }).then((res) => {
        const workbook = read(res.data)
        const sheetName = workbook.SheetNames[0]
        const worksheet = workbook.Sheets[sheetName]
        const jsonData = utils.sheet_to_json(worksheet, { defval: '' })
        localStorage.setItem('dataset', JSON.stringify(jsonData))
      })
    }
  }, [query.data])

  return query
}

export function useDataFieldQuery() {
  const query = useQuery({
    queryKey: ['dataFiled'],
    queryFn: getMyField,
    select: (res) => res.data,
    placeholderData: (): any => {
      return { data: [] }
    },
  })

  return query
}
